@@ -17,8 +17,10 @@ import code2api.configs as configs
 def cod_cpd(image_path, version='none', max_interval=configs.max_interval):
     if version == 'none':
         algorithm_name = 'cod_CPD'
-        algorithm_version = '1.0.0'
-        algorithm_port = 15127
+    else:
+        algorithm_name = version
+    algorithm_version = '1.0.0'
+    algorithm_port = 15127
     algorithm_ip   = '120.26.143.61'
     full_algorithm_name = algorithm_name + '-' + algorithm_version
     lower_name = full_algorithm_name.replace('-', '_').replace('.', '_').lower()
